@@ -1,4 +1,5 @@
 
+
 sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
                            plot.all.together = FALSE){
 
@@ -107,21 +108,21 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
                          direction = "long", sep = "")
     SBA.m2.ha$period <- factor(paste0("t", SBA.m2.ha$period),
                                levels = my.period.levels)
+    SBA.m2.ha$plot.id <- as.factor(SBA.m2.ha$id)
+
     if (by.stand){
-      my.plots$plot1 <- xyplot(t ~ period, groups = SBA.m2.ha$id,
-                               data = SBA.m2.ha, ylab = "SBA.m2.ha", type = "l",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      my.plots$plot1 <- ggplot(SBA.m2.ha, aes(x = period, y = t, color = plot.id,group=plot.id)) +
+        geom_line() + ylab("SBA.m2.ha")
+
     } else{
       SBA.m2.ha$plot.size.m2 <-
         sitrees.res$plot.data$plot.size.m2[match(SBA.m2.ha$id,
                                                  sitrees.res$plot.data$plot.id)]
       SBA.m2.ha$SBA.m2 <- with(SBA.m2.ha, t / 10000 * plot.size.m2)
       SBA.m2.ha <- aggregate( SBA.m2 ~ period, data = SBA.m2.ha, FUN = sum)
-      my.plots$plot1 <- xyplot(SBA.m2 ~ period, 
-                               data = SBA.m2.ha, ylab = "SBA.m2", type = "l",
-                               scales = list(alternating = 1,
-                                             tck = c(1,0)))
+
+      my.plots$plot1 <-
+        ggplot(SBA.m2.ha, aes(period, SBA.m2, group = 1))   + geom_line() + ylab("SBA.m2.ha")
       
     }
     data.summary$SBA.m2.ha <- SBA.m2.ha
@@ -135,22 +136,21 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
                         timevar = "period",
                         direction = "long", sep = "")
     stems.ha$period <- factor(paste0("t", stems.ha$period),
-                               levels = my.period.levels)
+                              levels = my.period.levels)
+   
     if (by.stand){
-      my.plots$plot2 <- xyplot(t ~ period, groups = stems.ha$id,
-                               data = stems.ha, ylab = "stems/ha", type = "l",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      my.plots$plot2 <- ggplot(stems.ha, aes(x = period, y = t, color = plot.id, group=plot.id)) +
+        geom_line() + ylab("stems/ha")
     } else {
       stems.ha$plot.size.m2 <-
         sitrees.res$plot.data$plot.size.m2[match(stems.ha$id,
                                                  sitrees.res$plot.data$plot.id)]
       stems.ha$stems <- with(stems.ha, t / 10000 * plot.size.m2)
       stems.ha <- aggregate( stems ~ period, data = stems.ha, FUN = sum)
-      my.plots$plot2 <- xyplot(stems ~ period, groups = stems.ha$id,
-                               data = stems.ha, ylab = "stems", type = "l",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      my.plots$plot2 <-
+        ggplot(stems.ha ,aes(period, stems, group = 1))   + geom_line() + ylab("stems/ha")
+      
+      
     }
     data.summary$stems.ha <- stems.ha
   }
@@ -163,25 +163,22 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
                           direction = "long", sep = "")
     heights.10$period <- factor(paste0("t", heights.10$period),
                                levels = my.period.levels)
+    heights.10$plot.id <- as.factor(heights.10$id)
     
-    my.plots$plot3 <- xyplot(t ~ period, groups = heights.10$id,
-                             data = heights.10,
-                             type = 'l',
-                             ylab = "Average height of the 10 tallest trees",
-                               scales = list(alternating = 1,
-                                             tck = c(1,0)))
+    my.plots$plot3 <- ggplot(heights.10, aes(x = period, y = t, color = plot.id, group=plot.id)) +
+        geom_line() + ylab("Average height of the 10 tallest trees")
     data.summary$heights.10 <- heights.10
   }
   
   ## plot4 --number of dead
   if (4 %in% plots){
     if (by.stand){
-      my.plots$plot4 <- xyplot(x ~ period,
-                               groups =  num.dead.trees.ha$plot.id,
-                               data = num.dead.trees.ha,
-                               main = "dead trees per ha", type = "l",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      num.dead.trees.ha$plot.id <- as.factor(num.dead.trees.ha$plot.id)
+
+      my.plots$plot4 <-
+        ggplot(num.dead.trees.ha, aes(x = period, y = x, color = plot.id,group=plot.id)) +
+        geom_line() + ylab( "dead trees per ha")
+      
     } else {
       num.dead.trees.ha$plot.size.m2 <-
         sitrees.res$plot.data$plot.size.m2[match(num.dead.trees.ha$plot.id,
@@ -189,11 +186,10 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
       num.dead.trees.ha$stems <- with(num.dead.trees.ha, x / 10000 * plot.size.m2)
       num.dead.trees.ha <- aggregate( stems ~ period,
                                      data = num.dead.trees.ha, FUN = sum)
-      my.plots$plot4 <- xyplot(stems ~ period, 
-                               data = num.dead.trees.ha,
-                               main = "number of dead trees", type = "l",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      my.plots$plot4 <-
+        ggplot(num.dead.trees.ha, aes(period, stems, group = 1))   +
+        geom_line() + ylab("dead trees per ha")
+      
     }
     data.summary$num.dead.trees.ha <- num.dead.trees.ha
   }
@@ -201,12 +197,11 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
   ## plot5 --number of trees harvest
   if (5 %in% plots){
     if (by.stand){
-      my.plots$plot5 <- xyplot(x ~ period , data = num.removed.trees.ha,
-                               groups =  num.removed.trees.ha$plot.id,
-                               main = "removed trees per ha", type = "b",
-                               ylab = "number of trees removed",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      num.removed.trees.ha$plot.id <- as.factor(num.removed.trees.ha$plot.id)
+       
+      my.plots$plot5 <-
+        ggplot(num.removed.trees.ha, aes(x = period, y = x, color = plot.id,group=plot.id)) +
+        geom_line() + ylab( "removed trees per ha")
     } else {
       num.removed.trees.ha$plot.size.m2 <-
         sitrees.res$plot.data$plot.size.m2[match(num.removed.trees.ha$plot.id,
@@ -215,12 +210,13 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
         with(num.removed.trees.ha, x / 10000 * plot.size.m2)
       num.removed.trees.ha <- aggregate( stems ~ period,
                                         data = num.removed.trees.ha, FUN = sum)
-      my.plots$plot5 <- xyplot(stems ~ period , data = num.removed.trees.ha,
-                               
-                               main = "removed trees", type = "b",
-                               ylab = "number of trees removed",
-                               scales = list(alternating = 1,
-                                tck = c(1,0)))
+      my.plots$plot5 <-
+        ggplot(num.removed.trees.ha,
+               aes(period, stems, group = 1))   + geom_line() + ylab("removed trees per ha")
+      
+
+
+
     }
     data.summary$num.removed.trees.ha <- num.removed.trees.ha
   }
@@ -258,12 +254,12 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
           return(x)
         })
         xx <- rbindlist(xx, idcol = 'id.plot')
+       
+       
+
+        my.plots[['all_plots_figure']]  <- ggplot(xx, aes(period, t, group = id, col = id))   + geom_line()+
+          facet_wrap(~id.plot, scales = "free") + ylab("")
         
-        print(xyplot(t ~ period|id.plot, data = xx, type = "b", groups = xx$id,
-                     scales = list (y = list(relation = "free"),
-                                             alternating = 1,
-                                tck = c(1,0))
-                                    ))
         
       } else {
         if(1 %in% plots) SBA.m2 <- SBA.m2.ha[,c("period", "SBA.m2")] else {
@@ -280,11 +276,11 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
           } else num.removed.trees.ha <- NA
         
         xx <- list(
-          SBA.m2 = SBA.m2,
-          stems = stems,
+          SBA.m2.ha = SBA.m2,
+          stems.ha = stems,
           heights.10 =  heights.10,
-          num.dead.trees = num.dead.trees.ha,
-          num.removed.trees = num.removed.trees.ha
+          num.dead.trees.ha = num.dead.trees.ha,
+          num.removed.trees.ha = num.removed.trees.ha
           )
           
         xx[!1:5 %in% plots] <- NULL
@@ -296,15 +292,13 @@ sitree.summary <- function(sitrees.res, plots, by.stand = TRUE, plot = FALSE,
         })
         xx <- rbindlist(xx, idcol = 'id.plot')
 
-        print(
-          xyplot(t ~ period|id.plot, data = xx,
-                 type = "b",
-                 groups = xx$id,
-                 scales = list (y = list(relation = "free"), alternating = 1,
-                                tck = c(1,0)),
-                 ylab = "")
-        )
+        xx$id  <-  as.factor(xx$id)
         
+        my.plots[['all_plots_figure']]  <-  ggplot(xx, aes(period, t, group = id, col = id))   + geom_line()+
+            facet_wrap(~id.plot, scales = "free") + ylab("")
+        
+     
+            
       }## end if by.stand
       
     } else { ## if plot.all.together
